the folder where the BEAST2 is installed.
Note that this is not the folder where the BEAST2 executable is installed:
the BEAST2 executable is in a subfolder.
Use get_default_beast2_folder
to get the default BEAST2 folder.
Use get_default_beast2_bin_path
to get the full path to the default BEAST2 executable.
Use get_default_beast2_jar_path
to get the full path to the default BEAST2 jar file.
has_internet
boolean to indicate if the user has access to the
internet. By default, this value equals the result
of curl::has_internet
Author
Richèl J.C. Bilderbeek
Details
To be able to check this, an internet connection is needed.
Without an internet connection, NULL is returned.
See Also
Use is_beast2_ns_pkg_installed
to see if the NS package is installed without an internet connection